/* Kelsey Reiman 
   July 2014
   Bottle.js 
   
   This creates a bottle rotated around the y axis. It takes in a radius, height
   and color as parameters.
   
   */

Bottle = function (r , h, hexColor, bottleOpacity){

		var bottleObject = new THREE.Object3D();
		
		//create an array of points for the spline curve for the outside of the bottle
		var points = [];
	
		//THE ORDER OF THE POINTS REALLLY MATTERS
		points.push(new THREE.Vector3(0,0,0.15*h));
		points.push(new THREE.Vector3(0.2 * r,0,0.15*h));
		points.push(new THREE.Vector3(.6*r,0,0.1*h));
		points.push(new THREE.Vector3(r,0,0));
		points.push(new THREE.Vector3(r,0,0.5*h));
		points.push(new THREE.Vector3(0.8*r,0,0.6*h));
		points.push(new THREE.Vector3(0.4*r,0,0.7*h));
		points.push(new THREE.Vector3(0.4*r,0,0.97*h));
		points.push(new THREE.Vector3(0.45*r,0,0.97*h));
		points.push(new THREE.Vector3(0.45*r,0,h));
		points.push(new THREE.Vector3(0.4*r,0,h));

		//then make a spline curve to interpolate the curve between the points
		curve = new THREE.SplineCurve3(points);
		//then specify the number of points on that curve and make it into an array of points
		var numPoints = 50;
		var splinePoints = curve.getPoints(numPoints);
		
		
		
		//make a new lathe geometry out of of the array of points you just created
		//var geometry = new THREE.LatheGeometry( splinePoints,10,0,Math.PI);
		var geometry = new THREE.LatheGeometry( splinePoints,100);  
		var glassMaterial = new THREE.MeshPhongMaterial({color: hexColor, 
														 transparent: true, 
														 opacity: bottleOpacity,
														 shininess: 200,
														 specular: 0xFAFAC8}); 
		var outside = new THREE.Mesh(geometry,glassMaterial);
		outside.castShadow = true;
		outside.receiveShadow = true;
		
		outside.rotation.x = - Math.PI / 2.0 ;
		bottleObject.add( outside );
		
		/* Make inside of bottle */
		var insidePoints = [];
		

		//same as outside of bottle but the points are in the opposite order
		insidePoints.push(new THREE.Vector3(0.4*r,0,h));
		insidePoints.push(new THREE.Vector3(0.45*r,0,h));
		insidePoints.push(new THREE.Vector3(0.45*r,0,0.97*h));	
		insidePoints.push(new THREE.Vector3(0.4*r,0,h));
		insidePoints.push(new THREE.Vector3(0.4*r,0,0.7*h));
		insidePoints.push(new THREE.Vector3(0.8*r,0,0.6*h));
		insidePoints.push(new THREE.Vector3(r,0,0.5*h));
		insidePoints.push(new THREE.Vector3(r,0,0));
		insidePoints.push(new THREE.Vector3(.6*r,0,0.1*h));
		insidePoints.push(new THREE.Vector3(0.2 * r,0,0.15*h));
		insidePoints.push(new THREE.Vector3(0,0,0.15*h));

		
		//then make a spline curve to interpolate the curve between the points
		insideCurve = new THREE.SplineCurve3(insidePoints);
		//then specify the number of points on that curve and make it into an array of points
		var numInsidePoints = 50;
		var insideSplinePoints = insideCurve.getPoints(numInsidePoints);
		
		
		
		//make a new lathe geometry out of of the array of points you just created
		//var geometry = new THREE.LatheGeometry( splinePoints,10,0,Math.PI);
		var insideGeometry = new THREE.LatheGeometry( insideSplinePoints,100);  
	 
		var inside = new THREE.Mesh(insideGeometry,glassMaterial);
		//inside.castShadow = true;
		//inside.receiveShadow = true;
		
		inside.rotation.x = - Math.PI / 2.0 ;
		bottleObject.add( inside );
		
		return bottleObject;
}