/* Kelsey Reiman
   July 2014
   
   Creates an apple with its origin at the center of the bottom. Takes in 
   two image files as parameters, one for the color map and one for the 
   bump map.

*/

Apple = function(colorMapPath, bumpMapPath){
    /* The body of the apple is created by making a spline curve and rotating
	around the z axis in order to create the latheGeometry that is the apple. */
	
	//create an array of points 
	var points = [];
	
	//THE ORDER OF THE POINTS REALLLY MATTERS
	points.push(new THREE.Vector3(0,0,1));
	points.push(new THREE.Vector3(3.5,0,0));
	points.push(new THREE.Vector3(5,0,5));
	points.push(new THREE.Vector3(7,0,9));
	points.push(new THREE.Vector3(5,0,12));
	points.push(new THREE.Vector3(3,0,12));
	points.push(new THREE.Vector3(0,0,10));

	//then make a spline curve to interpolate the curve between the points
	curve = new THREE.SplineCurve3(points);
	
	//then specify the number of points on that curve and make it into an array of points
	var numPoints = 100;
	var splinePoints = curve.getPoints(numPoints);



	//make a new lathe geometry out of of the array of points you just created
	var geometry = new THREE.LatheGeometry( splinePoints, 50);  

	//this uses the image that was passed in as a parameter
	var texture = THREE.ImageUtils.loadTexture(colorMapPath);
	
	//texture from http://jwhigham.files.wordpress.com/2010/05/cubeuniformclouds.jpg
	var appleBump = THREE.ImageUtils.loadTexture(bumpMapPath);
	
	//the skinMaterial is a phong material with a texture map for both
	//the color and the bump
	var skinMaterial = new THREE.MeshPhongMaterial({map: texture,
													  bumpMap: appleBump,
													  bumpScale: .08,
													  shininess: 60}); 
	var fruit = new THREE.Mesh( geometry, skinMaterial ); 

	//since the lathe geometry is created around the z axis, we rotate it
	//around the x axis so it looks like the apple is centered around the
	//y axis
	fruit.rotation.x = - Math.PI / 2.0 ;
	this.add( fruit );
	
	fruit.castShadow = true;
	fruit.receiveShadow = true;


	/****
	STEM
	****/
	/*the stem is made from a simple cylinder */
	var stemColor = THREE.ImageUtils.loadTexture("images/stem-Color.jpg");
	
	var stemG = new THREE.CylinderGeometry( .2, .1, 3, 10,10); 
	var stemMaterial = new THREE.MeshPhongMaterial({//color:0xC6CF29,
													  map: stemColor,
													  bumpMap: appleBump,
													  bumpScale: .015}); 
	var stem = new THREE.Mesh( stemG, stemMaterial );
	stem.translateY(11); 
	this.add( stem );
	
	stem.castShadow = true;
	stem.receiveShadow = true;

// 			
	this.castShadow = true;
	this.receiveShadow = true;
				
	return this;
}